==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ts/GraphicsViewPreferences_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+51"/>
        <source>Rulers and Scrollbars</source>
        <translation>Règles et barres de défilement</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show rulers</source>
        <translation>Afficher les règles</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show scrollbars</source>
        <translation>Montrer barres de défilement</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Cursor</source>
        <translation>Curseur</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show crosshairs</source>
        <translation>Montrer réticule</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show large crosshairs</source>
        <translation>Montrer réticule grande</translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="obsolete">Grille</translation>
    </message>
    <message>
        <source>Automatically scale grid</source>
        <translation type="obsolete">Échelle de la grille automatiquement</translation>
    </message>
    <message>
        <source>Solid grid lines</source>
        <translation type="obsolete">Lignes de grille pleines</translation>
    </message>
    <message>
        <source>Minimal grid spacing (px):</source>
        <translation type="obsolete">Espacement de grille minimal (px) :</translation>
    </message>
    <message>
        <source>Automatically scale meta grid</source>
        <translation type="obsolete">Échelle de la meta grille automatiquement</translation>
    </message>
    <message>
        <location line="-64"/>
        <source>Origin</source>
        <translation>Origine</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show large origin axis</source>
        <translation>Montrer réticule grande</translation>
    </message>
    <message>
        <location line="+71"/>
        <source>Auto Zoom</source>
        <translation>Zoom automatique</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Margin (px):</source>
        <translation>Marge (px) :</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Auto zoom on load</source>
        <translation>Zoom Auto après ouvrir</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Color Adjustment</source>
        <translation>Ajustement de la couleur</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Prevent white on white / black on black display</source>
        <translation>Correction automatique des couleurs en noir et blanc</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Color lightness threshold:</source>
        <translation>Seuil de couleur :</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Linetypes</source>
        <translation>Types de ligne</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Auto switch to screen based linetypes in model view</source>
        <translation>Utiliser automatiquement les types de lignes sur écran en vue du modèle</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale linetype patterns by line weight</source>
        <translation>Escaladez les motifs de ligne basés sur l&apos;épaisseur de ligne</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Pattern scale for lineweight 0.00mm:</source>
        <translation>Échelle du motif de l&apos;épaisseur de ligne 0.00mm:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Display and Performance</source>
        <translation>Affichage et performance</translation>
    </message>
    <message>
        <location line="+146"/>
        <source>Display entities with more than N dashes as continuous:</source>
        <translation>Afficher les entités de plus de N tirets que continu:</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Minimum angle step for rendering arcs (degrees):</source>
        <translation>Incrément angulaire minimum pour rendre arcs (degrés):</translation>
    </message>
    <message>
        <location line="+144"/>
        <source>Use full resolution for Retina display</source>
        <translation>Utilisez pleine résolution pour affichage Retina</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Anti-aliasing on by default</source>
        <translation>Antialiasing activé par défaut</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Maximum number of reference points displayed:</source>
        <translation>Nombre maximum de points de référence affichés :</translation>
    </message>
    <message>
        <location line="-76"/>
        <source>Timeout for hatch rendering:</source>
        <translation>Délai d&apos;attente pour hachure rendu :</translation>
    </message>
    <message>
        <source>Antialiasing on by default</source>
        <translation type="vanished">Antialiasing activé par défaut</translation>
    </message>
    <message>
        <source>Display entities with N dashes as continuous:</source>
        <translation type="obsolete">Afficher les entités avec N tirets que continu:</translation>
    </message>
    <message>
        <location line="-342"/>
        <source>Automatically use screen based linetypes in model view</source>
        <translation>Utiliser automatiquement les types de lignes sur écran en vue du modèle</translation>
    </message>
    <message>
        <source>Auto switch linetypes</source>
        <translation type="obsolete">Ajuster automatiquement les types de ligne</translation>
    </message>
    <message>
        <source>Performance</source>
        <translation type="vanished">Performance</translation>
    </message>
    <message>
        <location line="+78"/>
        <source>Number of preview entities:</source>
        <translation>Nombre d&apos;entités en aperçu :</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Text height display threshold (px):</source>
        <translation>Afficher limite pour le texte (px):</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Display arcs as lines below this angle (degrees):</source>
        <translation>Afficher arcs que les lignes ci-dessous cet angle (degrés):</translation>
    </message>
    <message>
        <source>Text height display threshold:</source>
        <translation type="obsolete">Afficher limite pour le texte:</translation>
    </message>
    <message>
        <location line="+339"/>
        <source>Selection</source>
        <translation>Sélection</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Persistent Selection</source>
        <translation>Sélection persistante</translation>
    </message>
</context>
<context>
    <name>GraphicsViewPreferences</name>
    <message>
        <source>Show rulers</source>
        <translation type="obsolete">Afficher les règles</translation>
    </message>
    <message>
        <source>Show scrollbars</source>
        <translation type="obsolete">Montrer barres de défilement</translation>
    </message>
    <message>
        <source>Show crosshairs</source>
        <translation type="obsolete">Montrer réticule</translation>
    </message>
    <message>
        <source>Show large crosshairs</source>
        <translation type="obsolete">Montrer réticule grande</translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="obsolete">Grille</translation>
    </message>
    <message>
        <source>Automatically scale grid</source>
        <translation type="obsolete">Échelle de la grille automatiquement</translation>
    </message>
    <message>
        <source>Solid grid lines</source>
        <translation type="obsolete">Lignes de grille pleines</translation>
    </message>
    <message>
        <source>Minimal grid spacing (px):</source>
        <translation type="obsolete">Espacement de grille minimal (px) :</translation>
    </message>
    <message>
        <source>Auto Zoom</source>
        <translation type="obsolete">Zoom automatique</translation>
    </message>
    <message>
        <source>Performance</source>
        <translation type="obsolete">Performance</translation>
    </message>
    <message>
        <source>Text height display threshold:</source>
        <translation type="obsolete">Afficher limite pour le texte:</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="obsolete">Prévisualisation</translation>
    </message>
    <message>
        <source>Number of preview entities:</source>
        <translation type="obsolete">Nombre d&apos;entités en aperçu :</translation>
    </message>
    <message>
        <source>Prevent white on white / black on black display</source>
        <translation type="obsolete">Correction automatique des couleurs en noir et blanc</translation>
    </message>
    <message>
        <source>Color Adjustment</source>
        <translation type="obsolete">Ajustement de la couleur</translation>
    </message>
    <message>
        <source>Color lightness threshold:</source>
        <translation type="obsolete">Seuil de couleur :</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation type="obsolete">Zoom</translation>
    </message>
    <message>
        <source>Rulers and Scrollbars</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Règles et barres de défilement</translation>
    </message>
    <message>
        <source>Show Scrollbars</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Montrer barres de défilement</translation>
    </message>
    <message>
        <source>Cursor</source>
        <translatorcomment>--google--
Mettre entité en sur&amp;brillance sous curseur de la souris
Mettre entité en surbrillance sous curseur de la souris
Le fichier image de revêtement &apos;%1&apos; n&apos;existe pas.</translatorcomment>
        <translation type="obsolete">Curseur</translation>
    </message>
    <message>
        <source>Show cross hairs</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Montrer réticule</translation>
    </message>
    <message>
        <source>Show large cross hairs</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Montrer poils grande croix</translation>
    </message>
    <message>
        <source>Margin (px):</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Marge (px) :</translation>
    </message>
    <message>
        <source>Entities</source>
        <translatorcomment>--google--
Crée un nouveau bloc à partir des entités existantes
Désélectionne toutes les entités
Désélectionne&amp;r entités coupées</translatorcomment>
        <translation type="obsolete">Entités</translation>
    </message>
    <message>
        <source>Auto correct black and white colors</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Correction automatique des couleurs en noir et blanc</translation>
    </message>
    <message>
        <source>Selection</source>
        <translation type="obsolete">Sélection</translation>
    </message>
    <message>
        <source>Persistent Selection</source>
        <translatorcomment>--google--
Sélections &amp;persistantes
Sélections persistantes</translatorcomment>
        <translation type="obsolete">Sélection persistante</translation>
    </message>
    <message>
        <location filename="../GraphicsViewPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Vue graphique</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Appearance</source>
        <translation>Apparence</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ts/GraphicsViewPreferences_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+51"/>
        <source>Rulers and Scrollbars</source>
        <translation>Règles et barres de défilement</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show rulers</source>
        <translation>Afficher les règles</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show scrollbars</source>
        <translation>Montrer barres de défilement</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Cursor</source>
        <translation>Curseur</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show crosshairs</source>
        <translation>Montrer réticule</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show large crosshairs</source>
        <translation>Montrer réticule grande</translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="obsolete">Grille</translation>
    </message>
    <message>
        <source>Automatically scale grid</source>
        <translation type="obsolete">Échelle de la grille automatiquement</translation>
    </message>
    <message>
        <source>Solid grid lines</source>
        <translation type="obsolete">Lignes de grille pleines</translation>
    </message>
    <message>
        <source>Minimal grid spacing (px):</source>
        <translation type="obsolete">Espacement de grille minimal (px) :</translation>
    </message>
    <message>
        <source>Automatically scale meta grid</source>
        <translation type="obsolete">Échelle de la meta grille automatiquement</translation>
    </message>
    <message>
        <location line="-64"/>
        <source>Origin</source>
        <translation>Origine</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show large origin axis</source>
        <translation>Montrer réticule grande</translation>
    </message>
    <message>
        <location line="+71"/>
        <source>Auto Zoom</source>
        <translation>Zoom automatique</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Margin (px):</source>
        <translation>Marge (px) :</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Auto zoom on load</source>
        <translation>Zoom Auto après ouvrir</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Color Adjustment</source>
        <translation>Ajustement de la couleur</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Prevent white on white / black on black display</source>
        <translation>Correction automatique des couleurs en noir et blanc</translation>
    </message>
    <message>
        <location line="-29"/>
        <source>Color lightness threshold:</source>
        <translation>Seuil de couleur :</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Disable for printing</source>
        <translation>Désactiver lors de l&apos;impression</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Linetypes</source>
        <translation>Types de ligne</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Auto switch to screen based linetypes in model view</source>
        <translation>Utiliser automatiquement les types de lignes sur écran en vue du modèle</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale linetype patterns by line weight</source>
        <translation>Escaladez les motifs de ligne basés sur l&apos;épaisseur de ligne</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Pattern scale for lineweight 0.00mm:</source>
        <translation>Échelle du motif de l&apos;épaisseur de ligne 0.00mm:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Display and Performance</source>
        <translation>Affichage et performance</translation>
    </message>
    <message>
        <location line="+229"/>
        <source>Display entities with more than N dashes as continuous:</source>
        <translation>Afficher les entités de plus de N tirets que continu:</translation>
    </message>
    <message>
        <location line="-82"/>
        <source>Minimum angle step for rendering arcs (degrees):</source>
        <translation>Incrément angulaire minimum pour rendre arcs (degrés):</translation>
    </message>
    <message>
        <location line="-134"/>
        <source>Use full resolution for Retina display</source>
        <translation>Utilisez pleine résolution pour affichage Retina</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Anti-aliasing on by default</source>
        <translation>Antialiasing activé par défaut</translation>
    </message>
    <message>
        <location line="+327"/>
        <source>Maximum number of reference points displayed:</source>
        <translation>Nombre maximum de points de référence affichés :</translation>
    </message>
    <message>
        <location line="-62"/>
        <source>Timeout for hatch rendering:</source>
        <translation>Délai d&apos;attente pour hachure rendu :</translation>
    </message>
    <message>
        <source>Antialiasing on by default</source>
        <translation type="vanished">Antialiasing activé par défaut</translation>
    </message>
    <message>
        <source>Display entities with N dashes as continuous:</source>
        <translation type="obsolete">Afficher les entités avec N tirets que continu:</translation>
    </message>
    <message>
        <location line="-343"/>
        <source>Automatically use screen based linetypes in model view</source>
        <translation>Utiliser automatiquement les types de lignes sur écran en vue du modèle</translation>
    </message>
    <message>
        <source>Auto switch linetypes</source>
        <translation type="obsolete">Ajuster automatiquement les types de ligne</translation>
    </message>
    <message>
        <source>Performance</source>
        <translation type="vanished">Performance</translation>
    </message>
    <message>
        <location line="+92"/>
        <source>Number of preview entities:</source>
        <translation>Nombre d&apos;entités en aperçu :</translation>
    </message>
    <message>
        <source>Text height display threshold (px):</source>
        <translation type="vanished">Afficher limite pour le texte (px):</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Display arcs as lines below this angle (degrees):</source>
        <translation>Afficher arcs que les lignes ci-dessous cet angle (degrés):</translation>
    </message>
    <message>
        <source>Text height display threshold:</source>
        <translation type="obsolete">Afficher limite pour le texte:</translation>
    </message>
    <message>
        <location line="+335"/>
        <source>Selection</source>
        <translation>Sélection</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Persistent Selection</source>
        <translation>Sélection persistante</translation>
    </message>
</context>
<context>
    <name>GraphicsViewPreferences</name>
    <message>
        <source>Show rulers</source>
        <translation type="obsolete">Afficher les règles</translation>
    </message>
    <message>
        <source>Show scrollbars</source>
        <translation type="obsolete">Montrer barres de défilement</translation>
    </message>
    <message>
        <source>Show crosshairs</source>
        <translation type="obsolete">Montrer réticule</translation>
    </message>
    <message>
        <source>Show large crosshairs</source>
        <translation type="obsolete">Montrer réticule grande</translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="obsolete">Grille</translation>
    </message>
    <message>
        <source>Automatically scale grid</source>
        <translation type="obsolete">Échelle de la grille automatiquement</translation>
    </message>
    <message>
        <source>Solid grid lines</source>
        <translation type="obsolete">Lignes de grille pleines</translation>
    </message>
    <message>
        <source>Minimal grid spacing (px):</source>
        <translation type="obsolete">Espacement de grille minimal (px) :</translation>
    </message>
    <message>
        <source>Auto Zoom</source>
        <translation type="obsolete">Zoom automatique</translation>
    </message>
    <message>
        <source>Performance</source>
        <translation type="obsolete">Performance</translation>
    </message>
    <message>
        <source>Text height display threshold:</source>
        <translation type="obsolete">Afficher limite pour le texte:</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="obsolete">Prévisualisation</translation>
    </message>
    <message>
        <source>Number of preview entities:</source>
        <translation type="obsolete">Nombre d&apos;entités en aperçu :</translation>
    </message>
    <message>
        <source>Prevent white on white / black on black display</source>
        <translation type="obsolete">Correction automatique des couleurs en noir et blanc</translation>
    </message>
    <message>
        <source>Color Adjustment</source>
        <translation type="obsolete">Ajustement de la couleur</translation>
    </message>
    <message>
        <source>Color lightness threshold:</source>
        <translation type="obsolete">Seuil de couleur :</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation type="obsolete">Zoom</translation>
    </message>
    <message>
        <source>Rulers and Scrollbars</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Règles et barres de défilement</translation>
    </message>
    <message>
        <source>Show Scrollbars</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Montrer barres de défilement</translation>
    </message>
    <message>
        <source>Cursor</source>
        <translatorcomment>--google--
Mettre entité en sur&amp;brillance sous curseur de la souris
Mettre entité en surbrillance sous curseur de la souris
Le fichier image de revêtement &apos;%1&apos; n&apos;existe pas.</translatorcomment>
        <translation type="obsolete">Curseur</translation>
    </message>
    <message>
        <source>Show cross hairs</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Montrer réticule</translation>
    </message>
    <message>
        <source>Show large cross hairs</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Montrer poils grande croix</translation>
    </message>
    <message>
        <source>Margin (px):</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Marge (px) :</translation>
    </message>
    <message>
        <source>Entities</source>
        <translatorcomment>--google--
Crée un nouveau bloc à partir des entités existantes
Désélectionne toutes les entités
Désélectionne&amp;r entités coupées</translatorcomment>
        <translation type="obsolete">Entités</translation>
    </message>
    <message>
        <source>Auto correct black and white colors</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Correction automatique des couleurs en noir et blanc</translation>
    </message>
    <message>
        <source>Selection</source>
        <translation type="obsolete">Sélection</translation>
    </message>
    <message>
        <source>Persistent Selection</source>
        <translatorcomment>--google--
Sélections &amp;persistantes
Sélections persistantes</translatorcomment>
        <translation type="obsolete">Sélection persistante</translation>
    </message>
    <message>
        <location filename="../GraphicsViewPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Vue graphique</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Appearance</source>
        <translation>Apparence</translation>
    </message>
</context>
</TS>
